#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup, find_packages

requires=['aliyun-python-sdk-core==2.13.36', 
          'aliyun-python-sdk-kms==2.15.0',
          'APScheduler==3.9.1', 
          'asgiref==3.4.1', 
          'async-timeout==4.0.2', 
          'backports.zoneinfo==0.2.1', 
          'cacheout==0.13.1', 
          'certifi==2022.6.15', 
          'cffi==1.15.0', 
          'chardet==3.0.4', 
          'click==8.0.4', 
          'colorama==0.4.5', 
          'crcmod==1.7', 
          'cryptography==37.0.2', 
          'dataclasses==0.8', 
          'Deprecated==1.2.13', 
          'Django==3.2.12', 
          'dynaconf==3.1.5', 
          'et-xmlfile==1.1.0', 
          'Flask==2.0.3',
          'idna==2.8', 
          'importlib-metadata==4.8.3', 
          'importlib-resources==5.4.0', 
          'influxdb==5.2.2', 
          'iso8601==1.0.2', 
          'itsdangerous==2.0.1', 
          'Jinja2==3.0.3', 
          'jmespath==0.10.0', 
          'joblib==1.0.1',
          'lml==0.1.0', 
          'MarkupSafe==2.0.1',
          'minio==7.1.9', 
          'more-itertools==4.3.0', 
          'mysql-connector==2.2.9', 
          'mysql-connector-python==8.0.27', 
          'openpyxl==3.0.10', 
          'oss2==2.15.0', 
          'packaging==21.3', 
          'pdfkit==1.0.0', 
          'pika==1.1.0',
          'protobuf==3.19.4', 
          'pycodestyle==2.8.0',
          'pycparser==2.21', 
          'pycryptodome==3.14.1', 
          'pyexcel==0.7.0', 
          'pyexcel-io==0.6.6', 
          'pyexcel-xls==0.7.0', 
          'pyexcel-xlsx==0.6.0', 
          'PyMySQL==0.9.3', 
          'pyparsing==3.0.9', 
          'PyPDF2==2.2.0',
          'python-dateutil==2.8.2',
          'pytz==2022.1', 
          'pytz-deprecation-shim==0.1.0.post0', 
          'PyYAML==4.2b4', 
          'redis==4.3.3', 
          'requests==2.22.0', 
          'retrying==1.3.3', 
          'scikit-learn==0.24.2', 
          'scipy==1.2.1', 
          'six==1.16.0', 
          'sqlparse==0.4.2', 
          'texttable==1.6.4', 
          'threadpoolctl==3.1.0', 
          'typing==3.7.4.1', 
          'typing_extensions==4.1.1', 
          'tzdata==2022.1', 
          'tzlocal==4.2', 
          'urllib3==1.25.11', 
          'Werkzeug==2.0.3', 
          'wget==3.2', 
          'wrapt==1.14.1',
          'xlrd==2.0.1', 
          'xlwt==1.3.0', 
          'zipp==3.6.0']

setup(name='negentropior',
      version='0.0.1',
      description='ILabor algorithm group tools 算法组常用工具方法',
      author='Yi OuYang, ZhiWen Wang',
      author_email='yiouyang143@gmail.com',
      packages=find_packages(),
      include_package_data=True,
      install_requires=requires,
)
